@@ -6,6 +6,7 @@ import { facilityRoutes } from './facility';
 import { healthRoutes } from './health';
 import { integrationRoutes } from './integrations';
 import { adminRoutes } from './admin';
+import { suggestionsRoutes } from './suggestions';
 
 export const buildRoutes = ctx => {
   const routes = express.Router();
@@ -16,6 +17,7 @@ export const buildRoutes = ctx => {
   routes.use('/health', healthRoutes);
   routes.use('/integration', integrationRoutes);
   routes.use('/admin', adminRoutes);
+  routes.use('/suggestions', suggestionsRoutes);
 
   return routes;
 };
