@@ -448,6 +448,7 @@ const InvoiceRecordPrintoutComponent = ({
   certificateData,
   discharge,
   getLocalisation,
+  getSetting,
   clinicianText,
   invoice,
   enablePatientInsurer,
@@ -473,7 +474,7 @@ const InvoiceRecordPrintoutComponent = ({
           />
         </CertificateHeader>
         <SectionSpacing />
-        <PatientDetails getLocalisation={getLocalisation} patient={patientData} />
+        <PatientDetails getLocalisation={getLocalisation} getSetting={getSetting} patient={patientData} />
         <SectionSpacing />
         <InvoiceEncounterDetails
           encounter={encounter}
